Learn R Programming

OVL.CI (version 0.1.1)

OVL_derivates_1: Numerical derivatives of the overlap functional (normal vs. 2-component mixture).

Description

Computes finite-difference approximations of the partial derivatives of the overlap coefficient with respect to the parameters in the case where the first group is modeled as a normal distribution and the second group as a two-component Gaussian mixture.

Usage

OVL_derivates_1(
  mu1_hat,
  mu2_hat,
  sigma1_hat,
  sigma2_hat,
  pi2_hat,
  h,
  intersec,
  OVL_mix
)

Value

A list with components deriv1deriv7.

Arguments

mu1_hat

Numeric scalar. Estimated mean for the normal group.

mu2_hat

Numeric vector of length 2. Estimated means for the mixture group.

sigma1_hat

Numeric scalar. Estimated standard deviation for the normal group.

sigma2_hat

Numeric vector of length 2. Estimated standard deviations for the mixture group.

pi2_hat

Either a numeric scalar in [0,1] giving the mixing proportion of the first component in the mixture, or a numeric vector of length 2 with elements summing to 1.

h

Positive numeric scalar. Base step size for finite differences.

intersec

Numeric vector. Intersection points used as cutpoints.

OVL_mix

Function that evaluates the overlap-related expression at cutpoints.

Details

This function is intended for internal use (delta-method variance estimation).