Learn R Programming

OVL.CI (version 0.1.1)

encontrar_raices: Identifies the roots of a univariate function over a given interval by subdividing the interval into smaller subintervals and applying uniroot on those subintervals where a sign change is detected.

Description

Identifies the roots of a univariate function over a given interval by subdividing the interval into smaller subintervals and applying uniroot on those subintervals where a sign change is detected.

Usage

encontrar_raices(intersection_function, interval, n_subintervals = 10)

Value

A numeric vector containing the distinct roots found within interval. If no roots are detected, an empty numeric vector is returned.

Arguments

intersection_function

A univariate numeric function whose roots are to be located.

interval

Numeric vector of length 2 specifying the lower and upper bounds of the search interval.

n_subintervals

Integer. Number of subintervals used to partition interval.