Computes finite-difference approximations of the partial derivatives of the overlap coefficient with respect to the parameters in the case where the first group is modeled as a normal distribution and the second group as a two-component Gaussian mixture.
OVL_derivates_1(
mu1_hat,
mu2_hat,
sigma1_hat,
sigma2_hat,
pi2_hat,
h,
intersec,
OVL_mix
)A list with components deriv1–deriv7.
Numeric scalar. Estimated mean for the normal group.
Numeric vector of length 2. Estimated means for the mixture group.
Numeric scalar. Estimated standard deviation for the normal group.
Numeric vector of length 2. Estimated standard deviations for the mixture group.
Either a numeric scalar in [0,1] giving the mixing proportion of the first component in the mixture, or a numeric vector of length 2 with elements summing to 1.
Positive numeric scalar. Base step size for finite differences.
Numeric vector. Intersection points used as cutpoints.
Function that evaluates the overlap-related expression at cutpoints.
This function is intended for internal use (delta-method variance estimation).