uniroot on those subintervals where a sign change is detected.Identifies the roots of a univariate function over a given interval by
subdividing the interval into smaller subintervals and applying
uniroot on those subintervals where a sign change is detected.
encontrar_raices(intersection_function, interval, n_subintervals = 10)A numeric vector containing the distinct roots found within interval.
If no roots are detected, an empty numeric vector is returned.
A univariate numeric function whose roots are to be located.
Numeric vector of length 2 specifying the lower and upper bounds of the search interval.
Integer. Number of subintervals used to partition
interval.